@@ -360,7 +360,6 @@ use YATT::Lite::Constants;
     # element 引数
     foreach my $arg (lexpand($head), $body ? $body : (), lexpand($foot)) {
       my ($name, $expr) = @$arg[NODE_PATH, NODE_VALUE];
-      push @argExpr, $self->sync_curline($arg->[NODE_LNO]);
       my $formal = $add_arg->(ref $name ? $name->[-1] : $name);
       push @argExpr, ", ", $self->as_cast_to($formal, $expr);
     }
@@ -447,6 +446,9 @@ use YATT::Lite::Constants;
     (my MY $self, my ($var, $value)) = @_;
     'scalar(do {'.(ref $value ? $self->as_list(@$value) : $value).'})';
   }
+  sub as_cast_to_bool {
+    shift->as_cast_to_scalar(@_);
+  }
   sub as_cast_to_list {
     (my MY $self, my ($var, $value)) = @_;
     '['.(ref $value ? $self->as_list(@$value) : $value).']';
