@@ -21,6 +21,9 @@ BEGIN {
 	  DOCUMENT_URI
 
 	  QUERY_STRING
+	  CONTENT_TYPE
+	  CONTENT_LENGTH
+
 	  SERVER_NAME
 	  SERVER_PORT
 	  SERVER_PROTOCOL
@@ -37,6 +40,8 @@ BEGIN {
 	  HTTP_ACCEPT_ENCODING
 
 	  REMOTE_ADDR
+	  REMOTE_HOST
+	  REMOTE_USER
 	  HTTP_X_REAL_IP
 	  HTTP_X_CLIENT_IP
 	  HTTP_X_FORWARDED_FOR
